@@ -271,6 +271,16 @@ def get_threats_of_project_with_subattributes(project_id):
     return sorted(threats, key=lambda k: k['priority'])
 
 
+def get_unique_awameasures_of_project(project_id):
+    db = get_db()
+    awarenessmeasures = db.execute(
+        'SELECT DISTINCT pa.id, pa.name, pa.description, pa.percentage_executed, pa.needs_legal_attention, pa.legal_description, pa.project_id, pa.created_at, pa.due_date'
+        ' FROM project_awarenessmeasure pa'
+        ' WHERE pa.project_id = ?', (project_id,)
+    ).fetchall()
+
+    return awarenessmeasures
+
 def get_awarenessmeasures_of_project(project_id):
     db = get_db()
     awarenessmeasures = db.execute(
@@ -283,6 +293,17 @@ def get_awarenessmeasures_of_project(project_id):
 
     return awarenessmeasures
 
+def get_unique_countermeasures_of_project(project_id):
+    db = get_db()
+    countermeasures = db.execute(
+        'SELECT DISTINCT pc.id, pc.name, pc.description, pc.percentage_executed, pc.project_id, pc.created_at, pc.due_date'
+        ' FROM project_countermeasure pc'
+        ' WHERE pc.project_id = ?',
+        (project_id,)
+    ).fetchall()
+
+    return countermeasures
+
 
 def get_countermeasures_of_project(project_id):
     db = get_db()
@@ -304,6 +325,7 @@ def write_dashboard_worksheet(workbook, calculated_threats):
     data = []
     for threat in calculated_threats:
         data_to_write = (
+            threat['id'],
             threat['priority'],
             threat['name'],
             ', '.join([x['name'] for x in threat['countermeasures']]) if threat['countermeasures'] is not None and len(threat['countermeasures']) > 0 else None,
@@ -314,12 +336,13 @@ def write_dashboard_worksheet(workbook, calculated_threats):
         data.append(data_to_write)
 
     # Set the columns widths.
-    worksheet.set_column('A:F', 25)
-    worksheet.add_table('A1:F' + str(len(calculated_threats) + 1), {
+    worksheet.set_column('A:G', 25)
+    worksheet.add_table('A1:G' + str(len(calculated_threats) + 1), {
         'header_row': 1,
         'style': 'Table Style Medium 2',
         'data': data,
         'columns': [
+            {'header': 'Bedrohungs-ID'},
             {'header': 'Priorität'},
             {'header': 'Bedrohung'},
             {'header': 'technische/org Gegenmaßnahme'},
@@ -336,6 +359,7 @@ def write_threat_worksheet(workbook, calculated_threats):
     data = []
     for threat in calculated_threats:
         data_to_write = (
+            threat['id'],
             threat['priority'],
             threat['name'],
             threat['description'],
@@ -343,12 +367,13 @@ def write_threat_worksheet(workbook, calculated_threats):
         data.append(data_to_write)
 
     # Set the columns widths.
-    worksheet.set_column('A:D', 25)
-    worksheet.add_table('A1:D' + str(len(calculated_threats) + 1), {
+    worksheet.set_column('A:E', 25)
+    worksheet.add_table('A1:E' + str(len(calculated_threats) + 1), {
         'header_row': 1,
         'style': 'Table Style Medium 2',
         'data': data,
         'columns': [
+            {'header': 'Bedrohungs-ID'},
             {'header': 'Priorität'},
             {'header': 'Bedrohung'},
             {'header': 'Beschreibung'},
@@ -539,8 +564,10 @@ def export_as_excel(project_id):
     calculated_threats = get_threats_of_project_with_subattributes(project_id)
 
     awarenessmeasures = get_awarenessmeasures_of_project(project_id)
+    unique_awa_measures = get_unique_awameasures_of_project(project_id)
 
     countermeasures_of_project = get_countermeasures_of_project(project_id)
+    unique_countermeasures = get_unique_countermeasures_of_project(project_id)
 
     emp_groups = get_employee_groups(project_id)
 
@@ -575,7 +602,7 @@ def export_as_excel(project_id):
     path = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe()))) + "/" + filename
     workbook = xlsxwriter.Workbook(path)
 
-    write_report_worksheet(workbook, awarenessmeasures, countermeasures_of_project)
+    write_report_worksheet(workbook, unique_awa_measures, unique_countermeasures)
     write_dashboard_worksheet(workbook, calculated_threats)
     write_threat_worksheet(workbook, calculated_threats)
     write_countermeasures_worksheet(workbook, countermeasures_of_project)
@@ -602,7 +629,7 @@ def export_as_excel(project_id):
 def details(project_id):
     calculated_threats = get_threats_of_project_with_subattributes(project_id)
 
-    countermeasures_of_project = get_countermeasures_of_project(project_id)
+    countermeasures_of_project = get_unique_countermeasures_of_project(project_id)
     countermeasures_open = [x for x in countermeasures_of_project if x['percentage_executed'] is None or x['percentage_executed'] < 100]
 
     chart_data = []
@@ -648,7 +675,7 @@ def awareness_dashboard(project_id):
     next_month_start = this_month_start + relativedelta(months=+1)
     two_months_ahead_start = next_month_start + relativedelta(months=+1)
 
-    awarenessmeasures = get_awarenessmeasures_of_project(project_id)
+    awarenessmeasures = get_unique_awameasures_of_project(project_id)
     awarenessmeasures_past = [x for x in awarenessmeasures if x['due_date'] is not None and x['due_date'] < this_month_start]
     awarenessmeasures_this_month = [x for x in awarenessmeasures if x['due_date'] is not None and x['due_date'] > this_month_start and x['due_date'] < next_month_start]
     awarenessmeasures_next_month = [x for x in awarenessmeasures if x['due_date'] is not None and x['due_date'] > next_month_start and x['due_date'] < two_months_ahead_start]
