@@ -158,21 +158,21 @@ def delete(project_id):
     if 'deletion_object_id' not in request.form:
         error = "Die zu löschende ID wurde nicht gefunden."
         flash(error)
-        return index(project_id)
+        return redirect(url_for('threat.index', project_id=project_id))
 
     threat_id = request.form['deletion_object_id']
 
     if threat_id is None or threat_id == "":
         error = "Die zu löschende ID wurde nicht gefunden."
         flash(error)
-        return index(project_id)
+        return redirect(url_for('threat.index', project_id=project_id))
 
     threat = get_threat(project_id, threat_id)
 
     if threat is None:
         error = "Die zu löschende ID wurde nicht gefunden."
         flash(error)
-        return index(project_id)
+        return redirect(url_for('threat.index', project_id=project_id))
 
     db = get_db()
     db.execute('DELETE FROM project_threat_countermeasure WHERE threat_id = ?', (threat['id'], ))
@@ -187,7 +187,7 @@ def delete(project_id):
     db.execute('DELETE FROM project_threat WHERE id = ?', (threat['id'], ))
     db.commit()
 
-    return index(project_id)
+    return redirect(url_for('threat.index', project_id=project_id))
 
 ################# Countermeasures assigned to threat #####################
 
@@ -388,7 +388,7 @@ def clear_employee_groups_of_threat(project_id, threat_id):
 def get_employee_group(project_id, employee_id):
     db = get_db()
     emp_group = db.execute(
-        'SELECT id, name, description'
+        'SELECT id, name, description, project_id'
         ' FROM employee_group'
         ' WHERE id = ? AND project_id = ?', (employee_id, project_id)
     ).fetchone()
